:github_url: https://github.com/stephane-caron/lpsolvers/tree/main/doc/src/supported-solvers.rst

*****************
Supported solvers
*****************

CVXOPT
======

.. autofunction:: lpsolvers.cvxopt_solve_lp

CVXPY
=====

.. autofunction:: lpsolvers.cvxpy_solve_lp

cdd
===

.. autofunction:: lpsolvers.cdd_solve_lp
